==> content_management-0.1.0.gem: app/controllers/content_management/admin/content_statuses_controller.rb <==
module ContentManagement
  class Admin::ContentStatusesController < ContentManagementController
    # GET /content_statuses
    # GET /content_statuses.json
    def index
      @content_statuses = ContentStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @content_statuses }
      end
    end

    # GET /content_statuses/1
    # GET /content_statuses/1.json
    def show
      @content_status = ContentStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @content_status }
      end
    end

    # GET /content_statuses/new
    # GET /content_statuses/new.json
    def new
      @content_status = ContentStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @content_status }
      end
    end

    # GET /content_statuses/1/edit
    def edit
      @content_status = ContentStatus.find(params[:id])
    end

    # POST /content_statuses
    # POST /content_statuses.json
    def create
      @content_status = ContentStatus.new(params[:content_status])

      respond_to do |format|
        if @content_status.save
          format.html { redirect_to @content_status, :notice => 'Content status was successfully created.' }
          format.json { render :json => @content_status, :status => :created, :location => @content_status }
        else
          format.html { render :action => "new" }
          format.json { render :json => @content_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /content_statuses/1
    # PUT /content_statuses/1.json
    def update
      @content_status = ContentStatus.find(params[:id])

      respond_to do |format|
        if @content_status.update_attributes(params[:content_status])
          format.html { redirect_to @content_status, :notice => 'Content status was successfully updated.' }
          format.json { head :ok }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @content_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /content_statuses/1
    # DELETE /content_statuses/1.json
    def destroy
      @content_status = ContentStatus.find(params[:id])
      @content_status.destroy

      respond_to do |format|
        format.html { redirect_to content_statuses_url }
        format.json { head :ok }
      end
    end
  end
end

==> content_management-0.1.4.gem: app/controllers/content_management/admin/content_statuses_controller.rb <==
module ContentManagement
  class Admin::ContentStatusesController < ContentManagementController
    # GET /content_statuses
    # GET /content_statuses.json
    def index
      @content_statuses = ContentStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @content_statuses }
      end
    end

    # GET /content_statuses/1
    # GET /content_statuses/1.json
    def show
      @content_status = ContentStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @content_status }
      end
    end

    # GET /content_statuses/new
    # GET /content_statuses/new.json
    def new
      @content_status = ContentStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @content_status }
      end
    end

    # GET /content_statuses/1/edit
    def edit
      @content_status = ContentStatus.find(params[:id])
    end

    # POST /content_statuses
    # POST /content_statuses.json
    def create
      @content_status = ContentStatus.new(params[:content_status])

      respond_to do |format|
        if @content_status.save
          format.html { redirect_to @content_status, notice: 'Content status was successfully created.' }
          format.json { render json: @content_status, status: :created, location: @content_status }
        else
          format.html { render action: 'new' }
          format.json { render json: @content_status.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /content_statuses/1
    # PUT /content_statuses/1.json
    def update
      @content_status = ContentStatus.find(params[:id])

      respond_to do |format|
        if @content_status.update_attributes(params[:content_status])
          format.html { redirect_to @content_status, notice: 'Content status was successfully updated.' }
          format.json { head :ok }
        else
          format.html { render action: 'edit' }
          format.json { render json: @content_status.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /content_statuses/1
    # DELETE /content_statuses/1.json
    def destroy
      @content_status = ContentStatus.find(params[:id])
      @content_status.destroy

      respond_to do |format|
        format.html { redirect_to content_statuses_url }
        format.json { head :ok }
      end
    end
  end
end
